@@ -74,6 +74,8 @@ class SanitizerTestCase(TestCase):
             # ...but breaks without any additional content are still removed
             ("<a><br />  </a>", "<a> </a>"),
             ("<p>blab<br hello='world' />blub<p>", "<p>blab<br>blub</p>"),
+            ("<p>A & B</p>", "<p>A &amp; B</p>"),
+            ("<p>A &lt; B</p>", "<p>A &lt; B</p>"),
         ]
 
         self.run_tests(entries)
@@ -99,7 +101,7 @@ class SanitizerTestCase(TestCase):
     def test_03_merge(self):
         entries = (
             ("<h2>foo</h2><h2>bar</h2>", "<h2>foobar</h2>"),
-            ("<h2>foo  </h2>   <h2>   bar</h2>", "<h2>foo bar</h2> "),
+            ("<h2>foo  </h2>   <h2>   bar</h2>", "<h2>foo bar</h2>"),
         )
 
         self.run_tests(entries)
@@ -655,3 +657,34 @@ git commit
                 ("<br hello=\"alert('world');\"/><br>", "<br>"),
             ]
         )
+
+    def test_normalize_early(self):
+        self.run_tests(
+            [
+                (
+                    "\uff1cimg src=x onerror=\uff02alert(window.location)\uff02\uff1e",
+                    "",
+                ),
+            ]
+        )
+
+    def test_typographic_whitespace_tags_merging(self):
+        sanitizer = Sanitizer(
+            {
+                "whitespace": set(),
+                "keep_typographic_whitespace": True,
+            }
+        )
+        self.run_tests(
+            [
+                (
+                    "This is <strong>some</strong> <strong>text</strong> with adjacent tags.",
+                    "This is <strong>some text</strong> with adjacent tags.",
+                ),
+                (
+                    "This is <strong>some</strong> <strong>text</strong>with adjacent tags.",
+                    "This is <strong>some text</strong>with adjacent tags.",
+                ),
+            ],
+            sanitizer=sanitizer,
+        )
